"""
The Keithley doesn't like having its interface open and closed rapidly, so we can't do tests the way we normally would. In fact, this equipment's communication interface appears to be complete garbage, and terribly unreliable. The manufacturer should be ashamed. Agilent doesn't have the same issues. Neither does my garage-level equipment. Tsk tsk.
"""
from scippy import Keithley, ureg
from sciparse import assert_equal_qt
import time
import numpy as np
import pyvisa
import pytest
import pint
import serial
from numpy.testing import assert_equal, assert_allclose

@pytest.fixture
def timeout(keithley):
    time.sleep(0.2)
    yield None
    time.sleep(0.2)
    keithley['device'].output_on = False

@pytest.fixture(scope='session')
def keithley():
    print("Opening Keithley 2400 device...")
    keith = Keithley()
    keithley_parameters = {
        'device': keith,
        'id': 'KEITHLEY INSTRUMENTS INC.,MODEL 2400,1207317,C30   Mar 17 2006 09:29:29/A02  /K/J',
    }
    yield keithley_parameters
    print("Closing Keithley2400 device...")
    keithley_parameters['device'].reset()
    keithley_parameters['device'].close()

@pytest.mark.keithley
def test_visa_init(keithley, timeout):
    """
    Check that we get back the correct ID of our device
    """
    actual_device = keithley['device'].device
    desired_type = pyvisa.resources.serial.SerialInstrument
    assert_equal(type(actual_device), desired_type)

@pytest.mark.keithley
def test_identify(keithley, timeout):
    desired_name = keithley['id']
    actual_name = keithley['device'].identify()
    assert_equal(actual_name, desired_name)

@pytest.mark.keithley
def test_reset(keithley, timeout):
    keithley['device'].reset()
    desired_voltage = 0*ureg.V
    desired_current = 0*ureg.uA
    desired_voltage_compliance = 21*ureg.V
    desired_current_compliance = 105*ureg.uA

    actual_voltage = keithley['device'].voltage
    actual_current = keithley['device'].current.to(ureg.uA)
    actual_voltage_compliance = keithley['device'].voltage_compliance
    actual_current_compliance = keithley['device'].current_compliance.to(ureg.uA)

    assert_equal_qt(actual_voltage, desired_voltage)
    assert_equal_qt(actual_current, desired_current)
    assert_equal_qt(actual_current_compliance, desired_current_compliance)
    assert_equal_qt(actual_voltage_compliance, desired_voltage_compliance)

@pytest.mark.keithley
def test_set_voltage(keithley, timeout):
    desired_voltage = 10*ureg.V
    keithley['device'].voltage = 10
    keithley['device'].output_on = True
    actual_voltage = keithley['device'].voltage
    assert_equal_qt(actual_voltage, desired_voltage)

@pytest.mark.keithley
def test_set_voltage_units(keithley, timeout):
    desired_voltage = 10*ureg.V
    keithley['device'].voltage = desired_voltage
    keithley['device'].output_on = True
    actual_voltage = keithley['device'].voltage
    assert_equal_qt(actual_voltage, desired_voltage)

@pytest.mark.keithley
def test_set_current(keithley, timeout):
    desired_current = 10*ureg.mA
    keithley['device'].current = 0.01
    keithley['device'].output_on = True
    actual_current = keithley['device'].current
    assert_equal_qt(actual_current, desired_current)

@pytest.mark.keithley
def test_set_current_units(keithley, timeout):
    desired_current = 10*ureg.mA
    keithley['device'].current = desired_current
    keithley['device'].output_on = True
    actual_current = keithley['device'].current
    assert_equal_qt(actual_current, desired_current)

@pytest.mark.keithley
def test_set_current_compliance(keithley, timeout):
    desired_compliance = 1*ureg.mA
    keithley['device'].current_compliance = 0.001
    actual_compliance = keithley['device'].current_compliance
    assert_equal_qt(actual_compliance, desired_compliance)

@pytest.mark.keithley
def test_set_current_compliance_units(keithley, timeout):
    desired_compliance = 1*ureg.mA
    keithley['device'].current_compliance = desired_compliance
    actual_compliance = keithley['device'].current_compliance
    assert_equal_qt(actual_compliance, desired_compliance)

@pytest.mark.keithley
def test_set_voltage_compliance(keithley, timeout):
    desired_compliance = 1*ureg.V
    keithley['device'].voltage_compliance = 1
    actual_compliance = keithley['device'].voltage_compliance
    assert_equal_qt(actual_compliance, desired_compliance)

@pytest.mark.keithley
def test_set_voltage_compliance_units(keithley, timeout):
    desired_compliance = 1*ureg.V
    keithley['device'].voltage_compliance = desired_compliance
    actual_compliance = keithley['device'].voltage_compliance
    assert_equal_qt(actual_compliance, desired_compliance)

@pytest.mark.keithley
def test_set_voltage_to_current(keithley, timeout):
    """
    Check that we are switching from voltage mode to current mode when we assign a current.
    """
    keithley['device'].voltage = 1
    actual_mode = keithley['device'].mode
    desired_mode = 'voltage'
    assert_equal(actual_mode, desired_mode)

    keithley['device'].current = 1 * ureg.mA
    actual_mode = keithley['device'].mode
    desired_mode = 'current'
    assert_equal(actual_mode, desired_mode)

@pytest.mark.keithley
def test_set_current_to_voltage(keithley, timeout):
    """
    Check that we are switching from current mode to voltage mode when we assign a current.
    """
    keithley['device'].current = 1 * ureg.mA
    actual_mode = keithley['device'].mode
    desired_mode = 'current'
    assert_equal(actual_mode, desired_mode)

    keithley['device'].voltage = 1
    actual_mode = keithley['device'].mode
    desired_mode = 'voltage'
    assert_equal(actual_mode, desired_mode)

@pytest.mark.keithley
def test_measure_voltage(keithley, timeout):
    desired_voltage = 1 * ureg.V
    keithley['device'].voltage = desired_voltage
    actual_voltage, actual_current = keithley['device'].measure()
    assert_equal_qt(actual_voltage, desired_voltage)
    assert abs(actual_current) < 0.1*ureg.nA

@pytest.mark.keithley
def test_measure_current(keithley, timeout):
    desired_voltage = 21 * ureg.V
    keithley['device'].voltage_compliance = desired_voltage
    keithley['device'].current = 10*ureg.mA
    actual_voltage, actual_current = keithley['device'].measure()
    assert_equal_qt(actual_voltage, desired_voltage)
    assert abs(actual_current) < 0.01*ureg.mA

@pytest.mark.keithley
def test_measure_warning(keithley, timeout):
    with pytest.warns(UserWarning):
        keithley['device'].current = 0.01
        voltage, current = keithley['device'].measure()



from scippy import twos_to_integer, twos_to_voltage, count_to_voltage
import pytest
from numpy.testing import assert_equal, assert_allclose
import numpy as np

@pytest.mark.remote
def testTwosToInteger():
    """
    Check that this function converts a set of three bytes in twos complement to a signed integer. Checks
    two 3-byte arrays and one 6-byte array.
    """
    testBytes = np.array([255, 255, 255]) # check for proper sign conversion
    desiredInteger = -1
    actualInteger = twos_to_integer(testBytes)
    assert_equal(desiredInteger, actualInteger)

    testBytes = np.array([100, 255, 255])
    desiredInteger = 6619135
    actualInteger = twos_to_integer(testBytes)
    assert_equal(desiredInteger, actualInteger)

    testBytes = np.array([255, 255, 255, 100, 255, 255])
    desiredIntegers = np.array([-1, 6619135])
    actualIntegers = twos_to_integer(testBytes)
    assert_allclose(desiredIntegers, actualIntegers, atol=1e-5)

@pytest.mark.remote
def testCountToVoltage():
    """
    Test converting a raw ADC count into a voltage
    """
    desiredValue = 5.0
    actualCount = pow(2, 23)
    actualValue = count_to_voltage(actualCount, maxVoltage=5)
    assert_allclose(desiredValue, actualValue)

@pytest.mark.remote
def testTwosToVoltage():
    desiredVoltage = np.array([5.0])
    testBytes = np.array([127, 255, 255])
    actualVoltage = twos_to_voltage(testBytes, maxVoltage=5, differential=True)
    assert_allclose(desiredVoltage, actualVoltage, atol=1e-5)



import pint
ureg = pint.get_application_registry()

from scippy.source.SCPIDevice import SCPIDevice as SCPIDevice
from scippy.source.motor_controller import MotorController
from scippy.source.Agilent33210A import Agilent33210A as Agilent
from scippy.source.Keithley2400 import Keithley2400 as Keithley
from scippy.source.twos_postprocessing import *
from scippy.source.MCP3561 import MCP3561 as MCP



import pytest
import numpy as np
from scippy import MCP, twos_to_voltage
import matplotlib.pyplot as plt

@pytest.fixture
def mcp():
    device = MCP()
    device.reset()

    yield {'device': device}

    device.reset()
    device.close()

@pytest.mark.mcp
def testNoiseSpectralDensity(mcp):
    """
    Check that the noise spectral density of our ADC is less than some desired threshold far away
    from the location of our signal (assumed here at 1kHz)
    """
    # First, disable the motor so that the associated noise (hopefully) goes away
    mcp['device'].motorEnable = False

    desiredMeasurements = 10000
    halfMeasurements = int(desiredMeasurements/2)
    samplingFrequency = 4.68 # kHz
    frequencies = np.arange(0, samplingFrequency/2, samplingFrequency/desiredMeasurements)

    signalFrequency = 1 # kHz
    startNoiseFrequency = signalFrequency * 2
    stopNoiseFrequency = samplingFrequency/2
    noiseBandwidth = (stopNoiseFrequency - startNoiseFrequency)
    startNoiseBin = int(startNoiseFrequency / samplingFrequency * desiredMeasurements)

    mcp['device'].n_samples = desiredMeasurements
    data = mcp['device'].measure()
    times = np.arange(0, desiredMeasurements / samplingFrequency, 1/samplingFrequency)
    voltages = twos_to_voltage(data)
    dcOffset = np.mean(voltages)
    voltages -= dcOffset

    # The single-sided voltage spectral power (rms, by definition)
    voltageSpectralPower = np.square(np.abs(np.fft.fft(voltages/len(voltages))))[0:halfMeasurements]*2

    voltageNoiseRMS = np.sqrt(np.sum(voltageSpectralPower[startNoiseBin:]) )
    voltageNoisePSD = 1e9 * voltageNoiseRMS / np.sqrt(noiseBandwidth * 1e3) # in nV / rtHz

    noiseUpperBound = 400 # Differential converter: Bare ADC < 100, TIA ~1300
    print(f'Noise PSD: {voltageNoisePSD}')
    assert voltageNoisePSD < noiseUpperBound



import pytest
from scippy import MCP
from numpy.testing import assert_allclose, assert_equal
import time

@pytest.fixture
def mcp():
    device = MCP()
    device.reset()
    yield {'device': device}

    device.reset()
    device.close()

@pytest.mark.mcp
def testMotorPositionDefault(mcp):
    """
    Check that the motor position defaults to its expected value (0)
    """
    motor_position_desired = 0
    motor_position_actual = mcp['device'].motor_position
    assert_equal(motor_position_desired, motor_position_actual)
    """
    Check that the motor direction defaults to 0
    """
    motor_direction_desired = 0
    motor_direction_actual = mcp['device'].motor_direction
    assert_equal(motor_direction_actual, motor_direction_desired)

    motor_enable_desired = False
    motor_enable_actual = mcp['device'].motor_enable
    assert_equal(motor_enable_actual, motor_enable_desired)

@pytest.mark.mcp
def testMotorPositionCommunication(mcp):
    """
    Check that we can read and then write a motor position to the motor.
    """
    motor_position_desired = 100
    mcp['device'].motor_position = motor_position_desired
    motor_position_actual = mcp['device'].motor_position
    assert_equal(motor_position_actual, motor_position_desired)

@pytest.mark.mcp
def testMotorRotatingDefault(mcp):
    """
    Check that by default the motor does not think it is rotating
    """
    motor_rotating_desired = False
    motor_rotatingActual = mcp['device'].motor_rotating
    assert_equal(motor_rotatingActual, motor_rotating_desired)

@pytest.mark.mcp
def testMotorRotation(mcp):
    """
    Attempts to rotate the motor forward some, checks that the motor rotated, then attempts to rotate
    the motor backwards by some, and checks that it rotates. Also checks to see that the motor is in fact rotating
    after we give it the command.
    """
    motorRotationDesired = 100
    motor_position_desired = 0 + motorRotationDesired
    mcp['device'].rotate_motor(motorRotationDesired)
    motor_position_actual = mcp['device'].motor_position
    assert_equal(motor_position_actual, motor_position_desired)

    motorRotationDesired = -100
    motor_position_desired += motorRotationDesired
    mcp['device'].rotate_motor(motorRotationDesired)
    motor_position_actual = mcp['device'].motor_position
    assert_equal(motor_position_actual, motor_position_desired)

@pytest.mark.mcp
def testMotorAbortRotation(mcp):
    """
    Checks that after sending a motor rotation command we can abort that rotation successfully prior to the completion
    of the rotation.
    """
    motorRotation = 200
    mcp['device'].rotate_motor(motorRotation)
    mcp['device'].motor_enable = False
    time.sleep(0.05)
    motor_rotating_actual = mcp['device'].motor_rotating # check that the motor is no longer rotating
    assert_equal(motor_rotating_actual, False)

@pytest.mark.mcp
def testMotorSpeedDefault(mcp):
    """
    Check the default settings for motor speed.
    """
    motor_period_desired = 2
    motor_period_actual = mcp['device'].motor_period
    assert_equal(motor_period_actual, motor_period_desired)

@pytest.mark.mcp
def testMotorSpeed(mcp):
    """
    Check that we can successfully change the motor's period (and hence its speed)
    """
    motor_period_desired = 5;
    mcp['device'].motor_period = motor_period_desired
    motor_period_actual = mcp['device'].motor_period
    assert_equal(motor_period_actual, motor_period_desired)

@pytest.mark.mcp
def testMotorEnableDisableDefault(mcp):
    """
    Check that the motor is enabled by default
    """
    motor_enable_desired = False
    motor_enable_actual = mcp['device'].motor_enable
    assert_equal(motor_enable_actual, motor_enable_desired)

@pytest.mark.mcp
def testMotorEnableDisable(mcp):
    """
    Test enabling and disabling of the motor
    """
    motor_enable_desired = False
    mcp['device'].motor_enable = motor_enable_desired
    motor_enable_actual = mcp['device'].motor_enable
    assert_equal(motor_enable_actual, motor_enable_desired)

    motor_enable_desired = True
    mcp['device'].motor_enable = motor_enable_desired
    motor_enable_actual = mcp['device'].motor_enable
    assert_equal(motor_enable_actual, motor_enable_desired)



from scippy import SCPIDevice
import numpy as np
import pyvisa
import pytest
from numpy.testing import assert_equal, assert_allclose

@pytest.fixture
def agilent():
    print("Opening Agilent device...")
    agilent_parameters = {
        'device': SCPIDevice(),
        'id': 'Agilent Technologies,33210A,MY48005679,1.04-1.04-22-2',
    }
    yield agilent_parameters
    print("Closing Agilent device...")
    agilent_parameters['device'].close()

@pytest.mark.agilent
def test_visa_init(agilent):
    """
    Check that we get back the correct ID of our device
    """
    actual_device = agilent['device'].device
    desired_type = pyvisa.resources.usb.USBInstrument
    assert_equal(type(actual_device), desired_type)

@pytest.mark.agilent
def test_identify(agilent):
    desired_name = agilent['id']
    actual_name = agilent['device'].identify()
    assert_equal(actual_name, desired_name)

@pytest.mark.agilent
def test_read_termination(agilent):
    desired_termination = '\n'



import pytest
from scippy import MCP, Agilent, twos_to_integer
from numpy.testing import assert_equal
import numpy as np
import pandas as pd

@pytest.fixture
def mcp():
    device = MCP()
    device.reset()
    yield {'device': device}
    device.reset()
    device.close()

@pytest.fixture
def agilent():
    device = Agilent()
    device.reset()
    yield {'device': device}
    device.reset()
    device.close()

@pytest.mark.mcp
def test_measure_simple(mcp):
    """
    Asserts that the result of a measurement is a set of three bytes, and that no more than 3 bytes are returned
    """
    desiredMeasurements = 1
    measuredData = mcp['device'].measure()
    assert_equal(len(measuredData), 3)


@pytest.mark.mcp
def test_measure_byte_count(mcp):
    """
    Asserts that the Configure() function can be used to measure between 1 and 100,000 measurements without
    dropping a single byte.
    """
    desiredMeasurementsList = [1, 10, 100, 1000, 10000]

    for desiredMeasurements in desiredMeasurementsList:
        desiredBytes = desiredMeasurements * 3
        mcp['device'].n_samples = desiredMeasurements
        data = mcp['device'].measure()
        actualBytes = len(data)
        assert_equal(actualBytes, desiredBytes)

@pytest.mark.skip
@pytest.mark.mcp
def test_measure_large_byte_count(mcp):
    """
    Asserts that we can measure very large numbers of measurements (1 million in this test) without dropping
    any bytes.
    """
    desiredMeasurements = 500000
    desiredBytes = desiredMeasurements * 3
    mcp['device'].n_samples = desiredMeasurements
    data = mcp['device'].measure() # If this isn't blocking, it should probably be made blocking.
    actualBytes = len(data)
    assert_equal(actualBytes, desiredBytes)

@pytest.mark.mcp
def test_synchronization_points(mcp, agilent):
    """
    Confirm that we get the expected number of data synchronization events when we sample in a given time period.
    Assumes an external 1kHz square wave is being applied to pin 20 on the Teensy.
    """
    f_sync = 105
    desired_sync_pulses = 8
    n_samples = int(mcp['device'].sampling_frequency/f_sync * desired_sync_pulses)

    agilent['device'].frequency = f_sync
    agilent['device'].output_on = True
    agilent['device'].verify()

    mcp['device'].n_samples = n_samples
    mcp['device'].measure()

    actual_sync_pulses = mcp['device'].sync_points()
    assert_equal(actual_sync_pulses, desired_sync_pulses)

@pytest.mark.mcp
def test_synchronization_data(mcp, agilent):
    """
    Verify that the synchronization data we get is "reasonable" - that is that points are separated by very close
    to their expected frequency of 1kHz. This assumes there is a square wave at 1kHz sending data to the Teensy.
    """
    f_sync = 105
    desired_sync_pulses = 3
    n_samples = int(
            mcp['device'].sampling_frequency/f_sync * desired_sync_pulses)

    agilent['device'].frequency = f_sync
    agilent['device'].output_on = True
    agilent['device'].verify()

    mcp['device'].n_samples = n_samples
    mcp['device'].measure()
    actual_sync_pulses = mcp['device'].sync_points()
    syncData = mcp['device'].sync_data()
    bytesPerDataPoint = 3
    desiredSyncBytes = bytesPerDataPoint * desired_sync_pulses

    # check that the data has the right number of bytes in it
    assert_equal(len(syncData), desiredSyncBytes)
    measurementPoints = twos_to_integer(syncData)
    measurementDeltas = np.diff(measurementPoints)
    timeDeltas = 1 / mcp['device'].sampling_frequency * measurementDeltas
    approxFrequencies = np.reciprocal(timeDeltas)
    approx_frequency = np.mean(approxFrequencies)
    np.testing.assert_allclose(approx_frequency, f_sync, atol=1e-2)

@pytest.mark.mcp
def test_generate_data(mcp):
    n_samples = 1111
    mcp['device'].n_samples = n_samples
    data = mcp['device'].generate_data()

    fs = mcp['device'].sampling_frequency
    time_data_desired = np.arange(0, n_samples/fs, 1/fs)

    assert_equal(data.shape, (n_samples, 3))
    assert_equal(type(data), pd.DataFrame)
    same_names = (data.columns.values == ['Time (s)', 'Voltage (mV)', 'Sync'])
    assert_equal(all(same_names), True)

@pytest.mark.mcp
def test_generate_data_long(mcp):
    n_samples = 10000
    mcp['device'].n_samples = n_samples
    data = mcp['device'].generate_data()

    fs = mcp['device'].sampling_frequency
    time_data_desired = np.arange(0, n_samples/fs, 1/fs)

    assert_equal(data.shape, (n_samples, 3))
    assert_equal(type(data), pd.DataFrame)
    same_names = (data.columns.values == ['Time (s)', 'Voltage (mV)', 'Sync'])
    assert_equal(all(same_names), True)



from scippy import MCP
import numpy as np
import pyvisa
import serial
import pytest
from numpy.testing import assert_equal, assert_allclose

@pytest.fixture
def mcp():
    print("Opening MCP device...")
    mcp_parameters = {
        'device': MCP(),
        'id': 'MCP3561 Dev Board v1',
    }
    yield mcp_parameters
    print("Closing MCP device...")
    mcp_parameters['device'].reset()
    mcp_parameters['device'].close()

@pytest.mark.mcp
def test_pyserial_init(mcp):
    """
    Check that we get back the correct ID of our device
    """
    actual_device = mcp['device'].device
    desired_type = serial.serialposix.Serial
    assert_equal(type(actual_device), desired_type)

@pytest.mark.mcp
def test_identify(mcp):
    desired_name = mcp['id']
    actual_name = mcp['device'].identify()
    assert_equal(actual_name, desired_name)

@pytest.mark.mcp
def test_reset(mcp):
    pass

@pytest.mark.mcp
def test_verify(mcp):
    pass



from scippy import Agilent, ureg
import numpy as np
import pyvisa
import pytest
import pint
from numpy.testing import assert_equal, assert_allclose

@pytest.fixture
def agilent():
    print("Opening Agilent 33210A device...")
    agilent_parameters = {
        'device': Agilent(),
        'id': 'Agilent Technologies,33210A,MY48005679,1.04-1.04-22-2',
    }
    yield agilent_parameters
    print("Closing Agilent33210A device...")
    agilent_parameters['device'].reset()
    agilent_parameters['device'].close()

@pytest.mark.agilent
def test_visa_init(agilent):
    """
    Check that we get back the correct ID of our device
    """
    actual_device = agilent['device'].device
    desired_type = pyvisa.resources.usb.USBInstrument
    assert_equal(type(actual_device), desired_type)

@pytest.mark.agilent
def test_identify(agilent):
    desired_name = agilent['id']
    actual_name = agilent['device'].identify()
    assert_equal(actual_name, desired_name)

@pytest.mark.agilent
def test_reset(agilent):
    desired_frequency = 1000*ureg.Hz
    desired_amplitude = 0.1*ureg.V
    desired_offset = 0*ureg.V
    agilent['device'].reset()
    actual_frequency = agilent['device'].frequency
    actual_voltage = agilent['device'].amplitude
    actual_output = agilent['device'].output_on
    actual_offset = agilent['device'].offset_voltage

    assert actual_voltage == desired_amplitude
    assert actual_frequency == desired_frequency
    assert_equal(actual_output, False)
    assert actual_offset == desired_offset

@pytest.mark.agilent
def test_set_amplitude(agilent):
    desired_voltage = 0.5*ureg.V
    agilent['device'].amplitude= desired_voltage
    actual_voltage = agilent['device'].amplitude
    assert actual_voltage == desired_voltage

@pytest.mark.agilent
def test_set_amplitude_limit(agilent):
    desired_voltage = 9*ureg.mV # Smaller than we can handle
    minimum_amplitude = 0.01*ureg.V
    with pytest.raises(UserWarning):
        agilent['device'].amplitude = desired_voltage

    actual_amplitude = agilent['device'].amplitude
    desired_amplitude = minimum_amplitude
    assert actual_amplitude == desired_amplitude

def test_set_amplitude_units(agilent):
    desired_voltage = 50*ureg.mV
    agilent['device'].amplitude= desired_voltage
    actual_voltage = agilent['device'].amplitude
    assert actual_voltage == desired_voltage

@pytest.mark.agilent
def test_set_frequency(agilent):
    desired_frequency = 100*ureg.Hz
    agilent['device'].frequency = desired_frequency
    actual_frequency = agilent['device'].frequency
    assert actual_frequency == desired_frequency

@pytest.mark.agilent
def test_set_output(agilent):
    output_desired = True
    agilent['device'].output_on = True
    output_actual = agilent['device'].output_on
    assert_equal(output_actual, output_desired)

    output_desired = False
    agilent['device'].output_on = False
    output_actual = agilent['device'].output_on
    assert_equal(output_actual, output_desired)

@pytest.mark.agilent
def test_offset(agilent):
    offset_desired = 0.1*ureg.V
    agilent['device'].offset_voltage = offset_desired
    offset_actual = agilent['device'].offset_voltage
    assert offset_actual == offset_desired

@pytest.mark.agilent
def test_verify_correct(agilent):
    agilent['device'].verify()

@pytest.mark.agilent
def test_verify_incorrect_amplitude(agilent):
    agilent['device']._amplitude = 500 # This is just wrong
    with pytest.raises(AssertionError):
        agilent['device'].verify()

@pytest.mark.agilent
def test_verify_incorrect_frequency(agilent):
    agilent['device']._frequency = 99 # This is just wrong
    with pytest.raises(AssertionError):
        agilent['device'].verify()

@pytest.mark.agilent
def test_verify_incorrect_offset(agilent):
    agilent['device']._offset_voltage = 0.2 # This is just wrong
    with pytest.raises(AssertionError):
        agilent['device'].verify()

@pytest.mark.agilent
def test_verify_incorrect_output(agilent):
    agilent['device']._output_on = True # This is just wrong
    with pytest.raises(AssertionError):
        agilent['device'].verify()





"""
Adds the source files to the path for files in any subdirectory
"""
import os
import sys
print("Importing test context manager")

file_location = os.path.dirname(os.path.abspath(__file__))
source_location = os.path.abspath(os.path.join(file_location, '..', 'source/'))

sys.path.insert(0, source_location)
